@@ -84,8 +84,9 @@ LearnerClustAgnes = R6Class("LearnerClustAgnes",
       }
 
       warn_prediction_useless(self$id)
+      partition = self$assignments %??% stats::cutree(self$model, pv$k)
 
-      PredictionClust$new(task = task, partition = self$assignments)
+      PredictionClust$new(task = task, partition = partition)
     }
   )
 )
