@@ -68,7 +68,7 @@ LearnerClustFanny = R6Class("LearnerClustFanny",
 
     .predict = function(task) {
       warn_prediction_useless(self$id)
-      partition = self$model$clustering
+      partition = self$assignments %??% self$model$clustering
       prob = NULL
       if (self$predict_type == "prob") {
         prob = self$model$membership
