@@ -30,13 +30,6 @@ test_that("Learner properties are respected", {
     learner$param_set$values = parset
 
     p = learner$train(task)$predict(task)
-    expect_prediction_clust(p)
-
-    if ("complete" %chin% learner$properties) {
-      expect_prediction_complete(p, learner$predict_type)
-    }
-    if ("exclusive" %chin% learner$properties) {
-      expect_prediction_exclusive(p, learner$predict_type)
-    }
+    expect_prediction_clust(p, learner)
   }
 })
