@@ -3,9 +3,8 @@ skip_if_not_installed("ClusterR")
 test_that("autotest", {
   learner = lrn("clust.MBatchKMeans")
   expect_learner(learner)
-  task = generate_tasks(learner)
-  suppressWarnings(learner$train(task[[1L]]))
-  expect_class(learner$model, "MBatchKMeans")
+  result = run_autotest(learner)
+  expect_true(result, info = result$error)
 })
 
 test_that("Learner properties are respected", {
@@ -33,17 +32,7 @@ test_that("Learner properties are respected", {
       learner$param_set$values = parset
 
       p = learner$train(task)$predict(task)
-      expect_prediction_clust(p)
-
-      if ("complete" %chin% learner$properties) {
-        expect_prediction_complete(p, learner$predict_type)
-      }
-      if ("exclusive" %chin% learner$properties) {
-        expect_prediction_exclusive(p, "partition")
-      }
-      if (learner$predict_type == "prob") {
-        expect_prediction_fuzzy(p)
-      }
+      expect_prediction_clust(p, learner)
     }
   }
 })
