@@ -1,3 +1,5 @@
+skip_if_not_installed("protoclust")
+
 test_that("autotest", {
   learner = lrn("clust.protoclust")
   expect_learner(learner)
@@ -23,16 +25,6 @@ test_that("Learner properties are respected", {
     learner$param_set$values = parset
 
     p = suppressWarnings(learner$train(task)$predict(task))
-    expect_prediction_clust(p)
-
-    if ("complete" %chin% learner$properties) {
-      expect_prediction_complete(p, learner$predict_type)
-    }
-    if ("exclusive" %chin% learner$properties) {
-      expect_prediction_exclusive(p, learner$predict_type)
-    }
-    if ("fuzzy" %chin% learner$properties) {
-      expect_prediction_fuzzy(p)
-    }
+    expect_prediction_clust(p, learner)
   }
 })
